@@ -49,8 +49,8 @@ def make_intensifier_getter(
 
     Args:
         intensifiers (Dict[str, float]): A dictionary of intensifiers and multiplication factor.
-        lemmatize (bool, optional): Should it look up in the intensifiers using the lemma? Defaults to True.
-        lowercase (bool, optional): Should it look up in the intensifiers using the lowercased word? Defaults to True.
+        lemmatize (bool): Should it look up in the intensifiers using the lemma? Defaults to True.
+        lowercase (bool): Should it look up in the intensifiers using the lowercased word? Defaults to True.
 
     Returns:
         Callable[[Token], float]: The getter function
@@ -73,11 +73,11 @@ def make_intensifier_getter(
     return intensifier_scalar_getter
 
 
-def allcap_differential_getter(span: Span) -> bool:
+def allcap_differential_getter(span: Union[Span, Doc]) -> bool:
     """Check whether just some words in the span are ALL CAPS.
 
     Args:
-        span (Span): A spaCy span
+        span (Union[Span, Doc]): A spaCy span
 
     Returns:
         bool: `True` if some but not all items in `words` are ALL CAPS
@@ -97,17 +97,21 @@ def make_valance_getter(
     lexicon: Dict[str, float],
     lemmatize: bool = False,
     lowercase: bool = True,
-    cap_differential: Optional[float] = C_INCR,
+    cap_differential: float = C_INCR,
 ) -> Callable[[Token], float]:
     """Creates a token getter which return the valence (sentiment) of a token
     including the capitalization of the token.
 
     Args:
         lexicon (Dict[str, float]): The valence scores of the tokens.
-        lemmatize (bool, optional): Should it look up in the lexicon (and intensifiers) using the lemma? Defaults to True.
-        lowercase (bool, optional): Should it look up in the lexicon (and intensifiers) using the lowercased word? Defaults to True.
-        cap_differential (Optional[float], optional): Capitalization differential, which is added to the valence of the score it is emphasized using all caps.
-            Defaults to 0.733, an emperically derived constant (Hutto and Gilbert, 2014). If None it will not be used.
+        lemmatize (bool): Should it look up in the lexicon (and intensifiers)
+            using the lemma? Defaults to True.
+        lowercase (bool): Should it look up in the lexicon (and intensifiers)
+            using the lowercased word? Defaults to True.
+        cap_differential (float): Capitalization differential, which is added to the
+            valence of the score it is emphasized using all caps. Defaults to 0.733, an
+            emperically derived constant (Hutto and Gilbert, 2014). If None it will not
+            be used.
 
     Returns:
         Callable[[Token], float]: The getter function
@@ -153,8 +157,8 @@ def make_is_negation_getter(
 
     Args:
         negations (Iterable[str]): An list of negations
-        lemmatize (bool, optional): Should it look up in negations using the lemma? Defaults to True.
-        lowercase (bool, optional): Should it look up in negations using the lowercased word? Defaults to True.
+        lemmatize (bool): Should it look up in negations using the lemma? Defaults to True.
+        lowercase (bool): Should it look up in negations using the lowercased word? Defaults to True.
 
     Returns:
         Callable[[Token], bool]: A token getter
@@ -179,8 +183,8 @@ def make_is_contrastive_conj_getter(
 
     Args:
         contrastive_conjugations (Iterable[str]): A list of contrastive conjugations.
-        lemmatize (bool, optional): Should you lemmatize before lookup in the contrastive conjugations list? Defaults to True.
-        lowercase (bool, optional): Should you lowercase before lookup in the contrastive conjugations list? Defaults to True.
+        lemmatize (bool): Should you lemmatize before lookup in the contrastive conjugations list? Defaults to True.
+        lowercase (bool): Should you lowercase before lookup in the contrastive conjugations list? Defaults to True.
 
     Returns:
         Callable[[Token], bool]: A token getter
@@ -204,9 +208,9 @@ def make_is_negated_getter(
     the n previous workds are negations.
 
     Args:
-        lookback (int, optional): How many token should it look backwards for negations? Defaults to 3
+        lookback (int): How many token should it look backwards for negations? Defaults to 3
             which is emperically derived by Hutto and Gilbert (2014).
-        is_negation_getter (Optional[Callable[[Token], bool]], optional): A function which given a
+        is_negation_getter (Optional[Callable[[Token], bool]]): A function which given a
             token return if the token is a negation or not. If None it assumes that the the token
             extention "is_negation" is set. If specified overwrites teh extension. Defualts to None.
 
@@ -221,13 +225,14 @@ def make_is_negated_getter(
             + " or provide the is_negation_getter.",
         )
 
-    def is_negated_getter(token: Token) -> bool:
+    def is_negated_getter(token: Token) -> Optional[Token]:
         """Determine if token is negated."""
         # don't look back before the sentence start
         min_token_idx = max(token.sent.start, token.i - lookback)
         for t in token.doc[min_token_idx : token.i]:
             if t._.is_negation:
                 return t
+        return None
 
     return is_negated_getter
 
@@ -239,31 +244,36 @@ def make_token_polarity_getter(  # noqa: C901
     negation_scalar: float = N_SCALAR,
     lookback_intensities: List[float] = [1.0, 0.95, 0.90],
     **kwargs
-) -> Callable[[Token], float]:
+) -> Callable[[Token], TokenPolarityOutput]:
     """Creates a function (getter) which takes a token and return the polarity
     of the token based upon whether the token valence (sentiment) including
     whether is negated and whether it is intensified using an intensifier.
 
     Args:
-        valence_getter (Optional[Callable[[Token], float]]): a function which given a token return the
-            valence (sentiment) of the token. If None it assumes that the the token extention "valence"
-            is set. If specified it overwrites the extension. Defualts to None.
-        is_negated_getter (Optional[Callable[[Token], bool]], optional): A function which given a
-            token return a boolean indicating whether the token is negated. If None it assumes that the the token
-            extention "is_negated" is set. If specified it overwrites the extension. Defualts to None.
-        intensifier_getter (Optional[Callable[[Token], float]], optional): A getter which for a token
-            return 0 if it is not an intensifier or its intensifcation value if it is an intensifier.
-            E.g. the token 'especially' might have an value of 0.293 which increases or decreases the
-            valence of the following word by the specified amount. Defaults to None,
-            intensifiers aren't included in the analysis of token valence.
-        negation_scalar (float, optional):  Defaults to the emperically derived constant
+        valence_getter (Optional[Callable[[Token], float]]): a function which given a
+            token return the valence (sentiment) of the token. If None it assumes that
+            the the token extention "valence" is set. If specified it overwrites the
+            extension. Defualts to None.
+        is_negated_getter (Optional[Callable[[Token], bool]]): A function which given a
+            token return a boolean indicating whether the token is negated. If None it
+            assumes that the the token extention "is_negated" is set. If specified it
+            overwrites the extension. Defualts to None.
+        intensifier_getter (Optional[Callable[[Token], float]]): A getter which for a
+            token return 0 if it is not an intensifier or its intensifcation value if it
+            is an intensifier. E.g. the token 'especially' might have an value of 0.293
+            which increases or decreases the valence of the following word by the
+            specified amount. Defaults to None, intensifiers aren't included in the
+            analysis of token valence.
+        negation_scalar (float):  Defaults to the emperically derived constant
             -0.74 (Hutto and Gilbert, 2014).
-        lookback_intensities (List[float], optional): How long to look back for intensifiers
-            (length). Intensities indicate the how much to weight each intensifier. Defaults to
-            [1.0, 0.95, 0.90] which is emperically derived (Hutto and Gilbert, 2014).
+        lookback_intensities (List[float]): How long to look back for intensifiers
+            (length). Intensities indicate the how much to weight each intensifier.
+            Defaults to [1.0, 0.95, 0.90] which is emperically derived
+            (Hutto and Gilbert, 2014).
+        **kwargs: Additional keyword arguments.
 
     Returns:
-        Callable[[Token], float]: The getter function
+        Callable[[Token], TokenPolarityOutput]: The getter function
     """
     lookback = len(lookback_intensities)
 
@@ -292,7 +302,11 @@ def make_token_polarity_getter(  # noqa: C901
     if not Token.has_extension("intensifier"):
         Token.set_extension(
             "intensifier",
-            getter=make_intensifier_getter(False, False, {}),
+            getter=make_intensifier_getter(
+                intensifiers={},
+                lemmatize=False,
+                lowercase=False,
+            ),
         )
 
     def token_polarity_getter(
@@ -342,9 +356,17 @@ def make_token_polarity_getter(  # noqa: C901
     return token_polarity_getter
 
 
-def normalize(score, alpha=15):
+def normalize(score: float, alpha=15) -> float:
     """Normalize the score to be between -1 and 1 using an alpha that
-    approximates the max expected value."""
+    approximates the max expected value.
+
+    Args:
+        score (float): The score to normalize.
+        alpha (float): The alpha value to use for normalization. Defaults to 15.
+
+    Returns:
+        float: The normalized score.
+    """
     norm_score = score / math.sqrt((score * score) + alpha)
     if norm_score < -1.0:
         return -1.0
@@ -357,7 +379,7 @@ def questionmark_amplification(text: str) -> float:
     """Amplified the questions."""
     # check for added emphasis resulting from question marks (2 or 3+)
     qm_count = text.count("?")
-    qm_amplifier = 0
+    qm_amplifier = 0.0
     if qm_count > 1:
         if qm_count <= 3:
             # (empirically derived mean sentiment intensity rating increase for
@@ -420,25 +442,25 @@ def sift_sentiment_scores(sentiments: Iterable[float]) -> Tuple[float, float, in
 def make_span_polarity_getter(  # noqa: C901
     polarity_getter: Optional[Callable[[Token], float]],
     contrastive_conj_getter: Optional[Callable[[Token], bool]],
-) -> SpanPolarityOutput:
+) -> Callable[[Span], SpanPolarityOutput]:
     """Creates a function (getter) which for a span return the aggrated
     polarities. Including accounting for contrastive conjugations (e.g. 'but'),
     exclamationsmarks and questionmarks.
 
     Args:
-        polarity_getter (Optional[Callable[[Token], float]]): A function which given a token return
-            the polarity (sentiment) of the token. If None it assumes that the token extension
-            "polarity" is already set. If given it overwrites the "polarity" extension.
-            Defaults to None.
-        contrastive_conj (Set[str], optional): List or set of constrastive conjugations (e.g. 'but'),
-            these typically diminishes the sentiment before it and magnified the following statement
-            (e.g. "The food was good, but the service was horrible"). If None it assumes that the
-            token extension "is_contrastive_conj" is already set. If given it overwrites the extension.
-            Defaults to None.
+        polarity_getter (Optional[Callable[[Token], float]]): A function which given a
+            token return the polarity (sentiment) of the token. If None it assumes that
+            the token extension "polarity" is already set. If given it overwrites the
+            "polarity" extension. Defaults to None.
+        contrastive_conj_getter (Optional[Callable[[Token], bool]]): A function which
+            given a token return whether the token is a contrastive conjunction. If None
+            it assumes that the token extension "is_contrastive_conj" is already set. If
+            given it overwrites the "is_contrastive_conj" extension. Defaults to None.
 
     Returns:
-        PolarityOutput: An output object containing the aggregated polarity estimates along with the
-            polarities.
+        Callable[[Span], SpanPolarityOutput]: A function which for a span return the
+        aggrated polarities. Including accounting for contrastive conjugations (e.g.
+        'but'), exclamationsmarks and questionmarks.
     """
     if polarity_getter:
         Token.set_extension("polarity", getter=polarity_getter, force=True)
@@ -462,9 +484,9 @@ def make_span_polarity_getter(  # noqa: C901
     def __extract(polarity: TokenPolarityOutput) -> Tuple[float, Span]:
         return polarity.polarity, polarity.span
 
-    def polarity_getter(
+    def __polarity_getter(
         span: Span,
-        but_check: Optional[Callable] = but_check,
+        but_check: Callable = but_check,
     ) -> SpanPolarityOutput:
         polarities = [t._.polarity for t in span]
         sentiment, spans = zip(*[__extract(p) for p in polarities])
@@ -473,7 +495,7 @@ def make_span_polarity_getter(  # noqa: C901
 
         if sum_s:
             # compute and add emphasis from punctuation in text
-            punct_emph_amplifier = 0
+            punct_emph_amplifier = 0.0
             punct_emph_amplifier += questionmark_amplification(span.text)
             punct_emph_amplifier += exclamation_amplification(span.text)
             if sum_s > 0:
@@ -509,23 +531,26 @@ def make_span_polarity_getter(  # noqa: C901
             polarities=polarities,
         )
 
-    return polarity_getter
+    return __polarity_getter
 
 
 def make_doc_polarity_getter(
     span_polarity_getter: Optional[Callable[[Span], float]],
-) -> DocPolarityOutput:
+) -> Callable[[Doc], DocPolarityOutput]:
     """Creates a function (getter) which for a doc return the aggrated
     polarities. Including accounting for contrastive conjugations (e.g. 'but'),
     exclamationsmarks and questionmarks.
 
     Args:
-        span_polarity_getter (Optional[Callable[[Span], float]]):  a function which given a span return
-            the polarity (sentiment) of the span. If None it assumes that the the span extention
-            "polarity" is already set. If specified it overwrites the extension. Defaults to None.
+        span_polarity_getter (Optional[Callable[[Span], float]]):  a function which
+            given a span return the polarity (sentiment) of the span. If None it assumes
+            that the the span extention "polarity" is already set. If specified it
+            overwrites the extension. Defaults to None.
 
     Returns:
-        PolarityOutput: An output object containing the aggregated polarity estimates along with the polarities.
+        Callable[[Doc], DocPolarityOutput]: A function which given a doc return the
+            aggrated polarities. Including accounting for contrastive conjugations (e.g.
+            'but'), exclamationsmarks and questionmarks.
     """
 
     if span_polarity_getter:
